Module uim.codec.context
========================
Context
=======
This package contains structures to handle the encoding an decoding context, with information such as:

- Version of format
- Encoding scheme
- Encoding and decoding context for caching stroke information

Sub-modules
-----------
* uim.codec.context.decoder
* uim.codec.context.encoder
* uim.codec.context.scheme
* uim.codec.context.version